<!doctype html>
<html lang="en">

<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">

  <title>All Inspiration Single Sign-on</title>

  <link rel="stylesheet" href="static/styles/main.css">
  <link rel="icon" href="images/favicon.png">
</head>

<body>

  <div class="header">
    <img class="logo" src="static/images/allin_official.png" alt="All Inspiration">
  </div>

  <h2 class="heading">Single Sign-on</h2>

  <div class="main">

    <div id="discordLogin">
      <form action="discord-login" method="get">
        <button class="discord-login-button">
          <img class="discord-login-logo" src="static/images/discord-logo-white.svg">
          Sign-in using your Discord account
        </button>
      </form>
    </div>

  </div>

</body>

</html>
